diff --git a/DisplayMagician/DisplayMagician.csproj b/DisplayMagician/DisplayMagician.csproj
index a454225..a261d68 100644
--- a/DisplayMagician/DisplayMagician.csproj
+++ b/DisplayMagician/DisplayMagician.csproj
@@ -343,12 +343,16 @@
+
+
+
+
diff --git a/DisplayMagician/Program.cs b/DisplayMagician/Program.cs
index 643baa5..71b14c0 100644
--- a/DisplayMagician/Program.cs
+++ b/DisplayMagician/Program.cs
@@ -421,37 +421,6 @@ namespace DisplayMagician {
heliosIcon.Save(fs);
}
- // Save a copy of the Steam Icon, and all the game library ones in preparation for future use
- if (!File.Exists(AppSteamIconFilename))
- {
- Icon heliosIcon = (Icon)Properties.Resources.Steam;
- using (FileStream fs = new FileStream(AppSteamIconFilename, FileMode.Create))
- heliosIcon.Save(fs);
- }
-
- // Save a copy of the Uplay Icon, and all the game library ones in preparation for future use
- if (!File.Exists(AppUplayIconFilename))
- {
- Icon heliosIcon = (Icon)Properties.Resources.Uplay;
- using (FileStream fs = new FileStream(AppUplayIconFilename, FileMode.Create))
- heliosIcon.Save(fs);
- }
-
- // Save a copy of the Epic Icon, and all the game library ones in preparation for future use
- if (!File.Exists(AppEpicIconFilename))
- {
- Icon heliosIcon = (Icon)Properties.Resources.Epic;
- using (FileStream fs = new FileStream(AppEpicIconFilename, FileMode.Create))
- heliosIcon.Save(fs);
- }
-
- // Save a copy of the Origin Icon, and all the game library ones in preparation for future use
- if (!File.Exists(AppOriginIconFilename))
- {
- Icon heliosIcon = (Icon)Properties.Resources.Origin;
- using (FileStream fs = new FileStream(AppOriginIconFilename, FileMode.Create))
- heliosIcon.Save(fs);
- }
}
catch (Exception ex)
{
@@ -902,11 +871,11 @@ namespace DisplayMagician {
if (bm == null)
{
if (game.GameLibrary.Equals(SupportedGameLibraryType.Steam))
- bm = Properties.Resources.Steam.ToBitmap();
+ bm = Properties.Resources.Steam;
else if (game.GameLibrary.Equals(SupportedGameLibraryType.Uplay))
- bm = Properties.Resources.Uplay.ToBitmap();
+ bm = Properties.Resources.Uplay;
else if (game.GameLibrary.Equals(SupportedGameLibraryType.Origin))
- bm = Properties.Resources.Origin.ToBitmap();
+ bm = Properties.Resources.Origin;
else
bm = Properties.Resources.DisplayMagician.ToBitmap();
}
diff --git a/DisplayMagician/Properties/Resources.resx b/DisplayMagician/Properties/Resources.resx
index 870dec7..55d87a2 100644
--- a/DisplayMagician/Properties/Resources.resx
+++ b/DisplayMagician/Properties/Resources.resx
@@ -118,21 +118,9 @@
System.Resources.ResXResourceWriter, System.Windows.Forms, Version=4.0.0.0, Culture=neutral, PublicKeyToken=b77a5c561934e089
-
- ..\Resources\Epic.ico;System.Drawing.Icon, System.Drawing, Version=4.0.0.0, Culture=neutral, PublicKeyToken=b03f5f7f11d50a3a
-
..\Resources\DisplayMagician.ico;System.Drawing.Icon, System.Drawing, Version=4.0.0.0, Culture=neutral, PublicKeyToken=b03f5f7f11d50a3a
-
- ..\Resources\Origin.ico;System.Drawing.Icon, System.Drawing, Version=4.0.0.0, Culture=neutral, PublicKeyToken=b03f5f7f11d50a3a
-
-
- ..\Resources\Steam.ico;System.Drawing.Icon, System.Drawing, Version=4.0.0.0, Culture=neutral, PublicKeyToken=b03f5f7f11d50a3a
-
-
- ..\Resources\Uplay.ico;System.Drawing.Icon, System.Drawing, Version=4.0.0.0, Culture=neutral, PublicKeyToken=b03f5f7f11d50a3a
-
..\resources\redarrows.png;System.Drawing.Bitmap, System.Drawing, Version=4.0.0.0, Culture=neutral, PublicKeyToken=b03f5f7f11d50a3a
@@ -151,4 +139,16 @@
..\Resources\whitearrowsup.png;System.Drawing.Bitmap, System.Drawing, Version=4.0.0.0, Culture=neutral, PublicKeyToken=b03f5f7f11d50a3a
+
+ ..\Resources\Epic.png;System.Drawing.Bitmap, System.Drawing, Version=4.0.0.0, Culture=neutral, PublicKeyToken=b03f5f7f11d50a3a
+
+
+ ..\Resources\Origin.png;System.Drawing.Bitmap, System.Drawing, Version=4.0.0.0, Culture=neutral, PublicKeyToken=b03f5f7f11d50a3a
+
+
+ ..\Resources\Steam.png;System.Drawing.Bitmap, System.Drawing, Version=4.0.0.0, Culture=neutral, PublicKeyToken=b03f5f7f11d50a3a
+
+
+ ..\Resources\Uplay.png;System.Drawing.Bitmap, System.Drawing, Version=4.0.0.0, Culture=neutral, PublicKeyToken=b03f5f7f11d50a3a
+
\ No newline at end of file
diff --git a/DisplayMagician/Resources/Epic.ico b/DisplayMagician/Resources/Epic.ico
deleted file mode 100644
index 152a7eb..0000000
Binary files a/DisplayMagician/Resources/Epic.ico and /dev/null differ
diff --git a/DisplayMagician/Resources/Epic.png b/DisplayMagician/Resources/Epic.png
new file mode 100644
index 0000000..0226780
Binary files /dev/null and b/DisplayMagician/Resources/Epic.png differ
diff --git a/DisplayMagician/Resources/Origin.ico b/DisplayMagician/Resources/Origin.ico
deleted file mode 100644
index d153bc8..0000000
Binary files a/DisplayMagician/Resources/Origin.ico and /dev/null differ
diff --git a/DisplayMagician/Resources/Origin.png b/DisplayMagician/Resources/Origin.png
new file mode 100644
index 0000000..f4acc75
Binary files /dev/null and b/DisplayMagician/Resources/Origin.png differ
diff --git a/DisplayMagician/Resources/Steam.ico b/DisplayMagician/Resources/Steam.ico
deleted file mode 100644
index a7da702..0000000
Binary files a/DisplayMagician/Resources/Steam.ico and /dev/null differ
diff --git a/DisplayMagician/Resources/Steam.png b/DisplayMagician/Resources/Steam.png
new file mode 100644
index 0000000..6a14e84
Binary files /dev/null and b/DisplayMagician/Resources/Steam.png differ
diff --git a/DisplayMagician/Resources/Uplay.ico b/DisplayMagician/Resources/Uplay.ico
deleted file mode 100644
index fc13590..0000000
Binary files a/DisplayMagician/Resources/Uplay.ico and /dev/null differ
diff --git a/DisplayMagician/Resources/Uplay.png b/DisplayMagician/Resources/Uplay.png
new file mode 100644
index 0000000..9118eb6
Binary files /dev/null and b/DisplayMagician/Resources/Uplay.png differ
diff --git a/DisplayMagician/ShortcutItem.cs b/DisplayMagician/ShortcutItem.cs
index e8414cc..8d015bf 100644
--- a/DisplayMagician/ShortcutItem.cs
+++ b/DisplayMagician/ShortcutItem.cs
@@ -995,17 +995,17 @@ namespace DisplayMagician
if (_gameLibrary == SupportedGameLibraryType.Steam)
{
logger.Trace($"ShortcutItem/SaveShortcutIconToCache: Using the Steam icon as the icon instead.");
- bm = ToBitmapOverlay(Properties.Resources.Steam.ToBitmap(), _profileToUse.ProfileIcon.ToBitmap(),256,256);
+ bm = ToBitmapOverlay(Properties.Resources.Steam, _profileToUse.ProfileIcon.ToBitmap(),256,256);
}
else if (_gameLibrary == SupportedGameLibraryType.Uplay)
{
logger.Trace($"ShortcutItem/SaveShortcutIconToCache: Using the Uplay icon as the icon instead.");
- bm = ToBitmapOverlay(Properties.Resources.Uplay.ToBitmap(), _profileToUse.ProfileIcon.ToBitmap(), 256, 256);
+ bm = ToBitmapOverlay(Properties.Resources.Uplay, _profileToUse.ProfileIcon.ToBitmap(), 256, 256);
}
else if (_gameLibrary == SupportedGameLibraryType.Origin)
{
logger.Trace($"ShortcutItem/SaveShortcutIconToCache: Using the Origin icon as the icon instead.");
- bm = ToBitmapOverlay(Properties.Resources.Origin.ToBitmap(), _profileToUse.ProfileIcon.ToBitmap(), 256, 256);
+ bm = ToBitmapOverlay(Properties.Resources.Origin, _profileToUse.ProfileIcon.ToBitmap(), 256, 256);
}
si.Add(bm);
logger.Trace($"ShortcutItem/SaveShortcutIconToCache: Saving the replacement icon for Shortcut '{Name}' to {_savedShortcutIconCacheFilename}.");
@@ -1041,17 +1041,17 @@ namespace DisplayMagician
if (_gameLibrary == SupportedGameLibraryType.Steam)
{
logger.Trace($"ShortcutItem/SaveShortcutIconToCache: Using the Steam icon as the icon instead.");
- originalBitmap = Properties.Resources.Steam.ToBitmap();
+ originalBitmap = Properties.Resources.Steam;
}
else if (_gameLibrary == SupportedGameLibraryType.Uplay)
{
logger.Trace($"ShortcutItem/SaveShortcutIconToCache: Using the Uplay icon as the icon instead.");
- originalBitmap = Properties.Resources.Uplay.ToBitmap();
+ originalBitmap = Properties.Resources.Uplay;
}
else if (_gameLibrary == SupportedGameLibraryType.Origin)
{
logger.Trace($"ShortcutItem/SaveShortcutIconToCache: Using the Origin icon as the icon instead.");
- originalBitmap = Properties.Resources.Origin.ToBitmap();
+ originalBitmap = Properties.Resources.Origin;
}
}
else
diff --git a/DisplayMagician/UIForms/SettingsForm.Designer.cs b/DisplayMagician/UIForms/SettingsForm.Designer.cs
index b287cd2..d8b46e4 100644
--- a/DisplayMagician/UIForms/SettingsForm.Designer.cs
+++ b/DisplayMagician/UIForms/SettingsForm.Designer.cs
@@ -36,17 +36,17 @@ namespace DisplayMagician.UIForms
this.cmb_loglevel = new System.Windows.Forms.ComboBox();
this.cb_minimise_notification_area = new System.Windows.Forms.CheckBox();
this.gb_hotkeys = new System.Windows.Forms.GroupBox();
- this.btn_hotkey_main_window = new System.Windows.Forms.Button();
- this.btn_hotkey_display_profile = new System.Windows.Forms.Button();
- this.btn_hotkey_shortcuts = new System.Windows.Forms.Button();
- this.lbl_hotkey_main_window_description = new System.Windows.Forms.Label();
- this.lbl_hotkey_display_profile_description = new System.Windows.Forms.Label();
- this.lbl_hotkey_shortcut_library_description = new System.Windows.Forms.Label();
- this.btn_clear_all_hotkeys = new System.Windows.Forms.Button();
- this.lv_dynamic_hotkeys = new System.Windows.Forms.ListView();
- this.lbl_hotkey_main_window = new System.Windows.Forms.Label();
- this.lbl_hotkey_display_profile = new System.Windows.Forms.Label();
this.lbl_hotkey_shortcut_library = new System.Windows.Forms.Label();
+ this.lbl_hotkey_display_profile = new System.Windows.Forms.Label();
+ this.lbl_hotkey_main_window = new System.Windows.Forms.Label();
+ this.lv_dynamic_hotkeys = new System.Windows.Forms.ListView();
+ this.btn_clear_all_hotkeys = new System.Windows.Forms.Button();
+ this.lbl_hotkey_shortcut_library_description = new System.Windows.Forms.Label();
+ this.lbl_hotkey_display_profile_description = new System.Windows.Forms.Label();
+ this.lbl_hotkey_main_window_description = new System.Windows.Forms.Label();
+ this.btn_hotkey_shortcuts = new System.Windows.Forms.Button();
+ this.btn_hotkey_display_profile = new System.Windows.Forms.Button();
+ this.btn_hotkey_main_window = new System.Windows.Forms.Button();
this.gb_general.SuspendLayout();
this.gb_hotkeys.SuspendLayout();
this.SuspendLayout();
@@ -152,80 +152,44 @@ namespace DisplayMagician.UIForms
this.gb_hotkeys.TabStop = false;
this.gb_hotkeys.Text = "Hotkeys";
//
- // btn_hotkey_main_window
+ // lbl_hotkey_shortcut_library
//
- this.btn_hotkey_main_window.Anchor = ((System.Windows.Forms.AnchorStyles)((System.Windows.Forms.AnchorStyles.Top | System.Windows.Forms.AnchorStyles.Right)));
- this.btn_hotkey_main_window.FlatAppearance.MouseDownBackColor = System.Drawing.Color.IndianRed;
- this.btn_hotkey_main_window.FlatAppearance.MouseOverBackColor = System.Drawing.Color.Brown;
- this.btn_hotkey_main_window.FlatStyle = System.Windows.Forms.FlatStyle.Flat;
- this.btn_hotkey_main_window.Font = new System.Drawing.Font("Microsoft Sans Serif", 9.75F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
- this.btn_hotkey_main_window.ForeColor = System.Drawing.Color.White;
- this.btn_hotkey_main_window.Location = new System.Drawing.Point(412, 27);
- this.btn_hotkey_main_window.Name = "btn_hotkey_main_window";
- this.btn_hotkey_main_window.Size = new System.Drawing.Size(88, 33);
- this.btn_hotkey_main_window.TabIndex = 36;
- this.btn_hotkey_main_window.Text = "Set Hotkey";
- this.btn_hotkey_main_window.UseVisualStyleBackColor = true;
- this.btn_hotkey_main_window.Click += new System.EventHandler(this.btn_hotkey_main_window_Click);
+ this.lbl_hotkey_shortcut_library.Location = new System.Drawing.Point(236, 133);
+ this.lbl_hotkey_shortcut_library.Name = "lbl_hotkey_shortcut_library";
+ this.lbl_hotkey_shortcut_library.Size = new System.Drawing.Size(169, 16);
+ this.lbl_hotkey_shortcut_library.TabIndex = 47;
+ this.lbl_hotkey_shortcut_library.Text = "None Set";
+ this.lbl_hotkey_shortcut_library.TextAlign = System.Drawing.ContentAlignment.MiddleRight;
+ this.lbl_hotkey_shortcut_library.Click += new System.EventHandler(this.lbl_hotkey_shortcut_library_Click);
//
- // btn_hotkey_display_profile
+ // lbl_hotkey_display_profile
//
- this.btn_hotkey_display_profile.Anchor = ((System.Windows.Forms.AnchorStyles)((System.Windows.Forms.AnchorStyles.Top | System.Windows.Forms.AnchorStyles.Right)));
- this.btn_hotkey_display_profile.FlatAppearance.MouseDownBackColor = System.Drawing.Color.IndianRed;
- this.btn_hotkey_display_profile.FlatAppearance.MouseOverBackColor = System.Drawing.Color.Brown;
- this.btn_hotkey_display_profile.FlatStyle = System.Windows.Forms.FlatStyle.Flat;
- this.btn_hotkey_display_profile.Font = new System.Drawing.Font("Microsoft Sans Serif", 9.75F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
- this.btn_hotkey_display_profile.ForeColor = System.Drawing.Color.White;
- this.btn_hotkey_display_profile.Location = new System.Drawing.Point(411, 75);
- this.btn_hotkey_display_profile.Name = "btn_hotkey_display_profile";
- this.btn_hotkey_display_profile.Size = new System.Drawing.Size(89, 33);
- this.btn_hotkey_display_profile.TabIndex = 37;
- this.btn_hotkey_display_profile.Text = "Set Hotkey";
- this.btn_hotkey_display_profile.UseVisualStyleBackColor = true;
- this.btn_hotkey_display_profile.Click += new System.EventHandler(this.btn_hotkey_display_profile_Click);
+ this.lbl_hotkey_display_profile.Location = new System.Drawing.Point(236, 83);
+ this.lbl_hotkey_display_profile.Name = "lbl_hotkey_display_profile";
+ this.lbl_hotkey_display_profile.Size = new System.Drawing.Size(169, 16);
+ this.lbl_hotkey_display_profile.TabIndex = 46;
+ this.lbl_hotkey_display_profile.Text = "None Set";
+ this.lbl_hotkey_display_profile.TextAlign = System.Drawing.ContentAlignment.MiddleRight;
+ this.lbl_hotkey_display_profile.Click += new System.EventHandler(this.lbl_hotkey_display_profile_Click);
//
- // btn_hotkey_shortcuts
+ // lbl_hotkey_main_window
//
- this.btn_hotkey_shortcuts.Anchor = ((System.Windows.Forms.AnchorStyles)((System.Windows.Forms.AnchorStyles.Top | System.Windows.Forms.AnchorStyles.Right)));
- this.btn_hotkey_shortcuts.FlatAppearance.MouseDownBackColor = System.Drawing.Color.IndianRed;
- this.btn_hotkey_shortcuts.FlatAppearance.MouseOverBackColor = System.Drawing.Color.Brown;
- this.btn_hotkey_shortcuts.FlatStyle = System.Windows.Forms.FlatStyle.Flat;
- this.btn_hotkey_shortcuts.Font = new System.Drawing.Font("Microsoft Sans Serif", 9.75F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
- this.btn_hotkey_shortcuts.ForeColor = System.Drawing.Color.White;
- this.btn_hotkey_shortcuts.Location = new System.Drawing.Point(411, 125);
- this.btn_hotkey_shortcuts.Name = "btn_hotkey_shortcuts";
- this.btn_hotkey_shortcuts.Size = new System.Drawing.Size(88, 33);
- this.btn_hotkey_shortcuts.TabIndex = 38;
- this.btn_hotkey_shortcuts.Text = "Set Hotkey";
- this.btn_hotkey_shortcuts.UseVisualStyleBackColor = true;
- this.btn_hotkey_shortcuts.Click += new System.EventHandler(this.btn_hotkey_shortcuts_Click);
+ this.lbl_hotkey_main_window.Location = new System.Drawing.Point(237, 35);
+ this.lbl_hotkey_main_window.Name = "lbl_hotkey_main_window";
+ this.lbl_hotkey_main_window.Size = new System.Drawing.Size(169, 16);
+ this.lbl_hotkey_main_window.TabIndex = 45;
+ this.lbl_hotkey_main_window.Text = "None Set";
+ this.lbl_hotkey_main_window.TextAlign = System.Drawing.ContentAlignment.MiddleRight;
+ this.lbl_hotkey_main_window.Click += new System.EventHandler(this.lbl_hotkey_main_window_Click);
//
- // lbl_hotkey_main_window_description
+ // lv_dynamic_hotkeys
//
- this.lbl_hotkey_main_window_description.AutoSize = true;
- this.lbl_hotkey_main_window_description.Location = new System.Drawing.Point(26, 35);
- this.lbl_hotkey_main_window_description.Name = "lbl_hotkey_main_window_description";
- this.lbl_hotkey_main_window_description.Size = new System.Drawing.Size(185, 16);
- this.lbl_hotkey_main_window_description.TabIndex = 39;
- this.lbl_hotkey_main_window_description.Text = "Hotkey to open Main Window:";
- //
- // lbl_hotkey_display_profile_description
- //
- this.lbl_hotkey_display_profile_description.AutoSize = true;
- this.lbl_hotkey_display_profile_description.Location = new System.Drawing.Point(25, 83);
- this.lbl_hotkey_display_profile_description.Name = "lbl_hotkey_display_profile_description";
- this.lbl_hotkey_display_profile_description.Size = new System.Drawing.Size(243, 16);
- this.lbl_hotkey_display_profile_description.TabIndex = 40;
- this.lbl_hotkey_display_profile_description.Text = "Hotkey to open Display Profile Window:";
- //
- // lbl_hotkey_shortcut_library_description
- //
- this.lbl_hotkey_shortcut_library_description.AutoSize = true;
- this.lbl_hotkey_shortcut_library_description.Location = new System.Drawing.Point(25, 133);
- this.lbl_hotkey_shortcut_library_description.Name = "lbl_hotkey_shortcut_library_description";
- this.lbl_hotkey_shortcut_library_description.Size = new System.Drawing.Size(197, 16);
- this.lbl_hotkey_shortcut_library_description.TabIndex = 41;
- this.lbl_hotkey_shortcut_library_description.Text = "Hotkey to open Shortcut Library:";
+ this.lv_dynamic_hotkeys.HideSelection = false;
+ this.lv_dynamic_hotkeys.Location = new System.Drawing.Point(27, 177);
+ this.lv_dynamic_hotkeys.Name = "lv_dynamic_hotkeys";
+ this.lv_dynamic_hotkeys.Size = new System.Drawing.Size(473, 143);
+ this.lv_dynamic_hotkeys.TabIndex = 44;
+ this.lv_dynamic_hotkeys.UseCompatibleStateImageBehavior = false;
//
// btn_clear_all_hotkeys
//
@@ -243,44 +207,80 @@ namespace DisplayMagician.UIForms
this.btn_clear_all_hotkeys.UseVisualStyleBackColor = true;
this.btn_clear_all_hotkeys.Click += new System.EventHandler(this.btn_clear_all_hotkeys_Click);
//
- // lv_dynamic_hotkeys
+ // lbl_hotkey_shortcut_library_description
//
- this.lv_dynamic_hotkeys.HideSelection = false;
- this.lv_dynamic_hotkeys.Location = new System.Drawing.Point(27, 177);
- this.lv_dynamic_hotkeys.Name = "lv_dynamic_hotkeys";
- this.lv_dynamic_hotkeys.Size = new System.Drawing.Size(473, 143);
- this.lv_dynamic_hotkeys.TabIndex = 44;
- this.lv_dynamic_hotkeys.UseCompatibleStateImageBehavior = false;
+ this.lbl_hotkey_shortcut_library_description.AutoSize = true;
+ this.lbl_hotkey_shortcut_library_description.Location = new System.Drawing.Point(25, 133);
+ this.lbl_hotkey_shortcut_library_description.Name = "lbl_hotkey_shortcut_library_description";
+ this.lbl_hotkey_shortcut_library_description.Size = new System.Drawing.Size(197, 16);
+ this.lbl_hotkey_shortcut_library_description.TabIndex = 41;
+ this.lbl_hotkey_shortcut_library_description.Text = "Hotkey to open Shortcut Library:";
//
- // lbl_hotkey_main_window
+ // lbl_hotkey_display_profile_description
//
- this.lbl_hotkey_main_window.Location = new System.Drawing.Point(237, 35);
- this.lbl_hotkey_main_window.Name = "lbl_hotkey_main_window";
- this.lbl_hotkey_main_window.Size = new System.Drawing.Size(169, 16);
- this.lbl_hotkey_main_window.TabIndex = 45;
- this.lbl_hotkey_main_window.Text = "None Set";
- this.lbl_hotkey_main_window.TextAlign = System.Drawing.ContentAlignment.MiddleRight;
- this.lbl_hotkey_main_window.Click += new System.EventHandler(this.lbl_hotkey_main_window_Click);
+ this.lbl_hotkey_display_profile_description.AutoSize = true;
+ this.lbl_hotkey_display_profile_description.Location = new System.Drawing.Point(25, 83);
+ this.lbl_hotkey_display_profile_description.Name = "lbl_hotkey_display_profile_description";
+ this.lbl_hotkey_display_profile_description.Size = new System.Drawing.Size(243, 16);
+ this.lbl_hotkey_display_profile_description.TabIndex = 40;
+ this.lbl_hotkey_display_profile_description.Text = "Hotkey to open Display Profile Window:";
//
- // lbl_hotkey_display_profile
+ // lbl_hotkey_main_window_description
//
- this.lbl_hotkey_display_profile.Location = new System.Drawing.Point(236, 83);
- this.lbl_hotkey_display_profile.Name = "lbl_hotkey_display_profile";
- this.lbl_hotkey_display_profile.Size = new System.Drawing.Size(169, 16);
- this.lbl_hotkey_display_profile.TabIndex = 46;
- this.lbl_hotkey_display_profile.Text = "None Set";
- this.lbl_hotkey_display_profile.TextAlign = System.Drawing.ContentAlignment.MiddleRight;
- this.lbl_hotkey_display_profile.Click += new System.EventHandler(this.lbl_hotkey_display_profile_Click);
+ this.lbl_hotkey_main_window_description.AutoSize = true;
+ this.lbl_hotkey_main_window_description.Location = new System.Drawing.Point(26, 35);
+ this.lbl_hotkey_main_window_description.Name = "lbl_hotkey_main_window_description";
+ this.lbl_hotkey_main_window_description.Size = new System.Drawing.Size(185, 16);
+ this.lbl_hotkey_main_window_description.TabIndex = 39;
+ this.lbl_hotkey_main_window_description.Text = "Hotkey to open Main Window:";
//
- // lbl_hotkey_shortcut_library
+ // btn_hotkey_shortcuts
//
- this.lbl_hotkey_shortcut_library.Location = new System.Drawing.Point(236, 133);
- this.lbl_hotkey_shortcut_library.Name = "lbl_hotkey_shortcut_library";
- this.lbl_hotkey_shortcut_library.Size = new System.Drawing.Size(169, 16);
- this.lbl_hotkey_shortcut_library.TabIndex = 47;
- this.lbl_hotkey_shortcut_library.Text = "None Set";
- this.lbl_hotkey_shortcut_library.TextAlign = System.Drawing.ContentAlignment.MiddleRight;
- this.lbl_hotkey_shortcut_library.Click += new System.EventHandler(this.lbl_hotkey_shortcut_library_Click);
+ this.btn_hotkey_shortcuts.Anchor = ((System.Windows.Forms.AnchorStyles)((System.Windows.Forms.AnchorStyles.Top | System.Windows.Forms.AnchorStyles.Right)));
+ this.btn_hotkey_shortcuts.FlatAppearance.MouseDownBackColor = System.Drawing.Color.IndianRed;
+ this.btn_hotkey_shortcuts.FlatAppearance.MouseOverBackColor = System.Drawing.Color.Brown;
+ this.btn_hotkey_shortcuts.FlatStyle = System.Windows.Forms.FlatStyle.Flat;
+ this.btn_hotkey_shortcuts.Font = new System.Drawing.Font("Microsoft Sans Serif", 9.75F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
+ this.btn_hotkey_shortcuts.ForeColor = System.Drawing.Color.White;
+ this.btn_hotkey_shortcuts.Location = new System.Drawing.Point(411, 125);
+ this.btn_hotkey_shortcuts.Name = "btn_hotkey_shortcuts";
+ this.btn_hotkey_shortcuts.Size = new System.Drawing.Size(88, 33);
+ this.btn_hotkey_shortcuts.TabIndex = 38;
+ this.btn_hotkey_shortcuts.Text = "Set Hotkey";
+ this.btn_hotkey_shortcuts.UseVisualStyleBackColor = true;
+ this.btn_hotkey_shortcuts.Click += new System.EventHandler(this.btn_hotkey_shortcuts_Click);
+ //
+ // btn_hotkey_display_profile
+ //
+ this.btn_hotkey_display_profile.Anchor = ((System.Windows.Forms.AnchorStyles)((System.Windows.Forms.AnchorStyles.Top | System.Windows.Forms.AnchorStyles.Right)));
+ this.btn_hotkey_display_profile.FlatAppearance.MouseDownBackColor = System.Drawing.Color.IndianRed;
+ this.btn_hotkey_display_profile.FlatAppearance.MouseOverBackColor = System.Drawing.Color.Brown;
+ this.btn_hotkey_display_profile.FlatStyle = System.Windows.Forms.FlatStyle.Flat;
+ this.btn_hotkey_display_profile.Font = new System.Drawing.Font("Microsoft Sans Serif", 9.75F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
+ this.btn_hotkey_display_profile.ForeColor = System.Drawing.Color.White;
+ this.btn_hotkey_display_profile.Location = new System.Drawing.Point(411, 75);
+ this.btn_hotkey_display_profile.Name = "btn_hotkey_display_profile";
+ this.btn_hotkey_display_profile.Size = new System.Drawing.Size(89, 33);
+ this.btn_hotkey_display_profile.TabIndex = 37;
+ this.btn_hotkey_display_profile.Text = "Set Hotkey";
+ this.btn_hotkey_display_profile.UseVisualStyleBackColor = true;
+ this.btn_hotkey_display_profile.Click += new System.EventHandler(this.btn_hotkey_display_profile_Click);
+ //
+ // btn_hotkey_main_window
+ //
+ this.btn_hotkey_main_window.Anchor = ((System.Windows.Forms.AnchorStyles)((System.Windows.Forms.AnchorStyles.Top | System.Windows.Forms.AnchorStyles.Right)));
+ this.btn_hotkey_main_window.FlatAppearance.MouseDownBackColor = System.Drawing.Color.IndianRed;
+ this.btn_hotkey_main_window.FlatAppearance.MouseOverBackColor = System.Drawing.Color.Brown;
+ this.btn_hotkey_main_window.FlatStyle = System.Windows.Forms.FlatStyle.Flat;
+ this.btn_hotkey_main_window.Font = new System.Drawing.Font("Microsoft Sans Serif", 9.75F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
+ this.btn_hotkey_main_window.ForeColor = System.Drawing.Color.White;
+ this.btn_hotkey_main_window.Location = new System.Drawing.Point(412, 27);
+ this.btn_hotkey_main_window.Name = "btn_hotkey_main_window";
+ this.btn_hotkey_main_window.Size = new System.Drawing.Size(88, 33);
+ this.btn_hotkey_main_window.TabIndex = 36;
+ this.btn_hotkey_main_window.Text = "Set Hotkey";
+ this.btn_hotkey_main_window.UseVisualStyleBackColor = true;
+ this.btn_hotkey_main_window.Click += new System.EventHandler(this.btn_hotkey_main_window_Click);
//
// SettingsForm
//
diff --git a/DisplayMagician/UIForms/SettingsForm.cs b/DisplayMagician/UIForms/SettingsForm.cs
index 65fed18..e96ee85 100644
--- a/DisplayMagician/UIForms/SettingsForm.cs
+++ b/DisplayMagician/UIForms/SettingsForm.cs
@@ -108,7 +108,6 @@ namespace DisplayMagician.UIForms
lv_dynamic_hotkeys.View = View.Details;
lv_dynamic_hotkeys.GridLines = true;
lv_dynamic_hotkeys.FullRowSelect = true;
- lv_dynamic_hotkeys.ShowGroups = true;
//Add column header
lv_dynamic_hotkeys.Columns.Add("Name", 300);
@@ -340,9 +339,9 @@ namespace DisplayMagician.UIForms
testHotkey = Program.AppProgramSettings.HotkeyShortcutLibraryWindow;
else
testHotkey = Keys.None;
- string hotkeyHeading = $"Choose a Hotkey for the Display Profile window";
+ string hotkeyHeading = $"Choose a Hotkey for the Shortcut Library window";
string hotkeyDescription = $"Choose a Hotkey (a keyboard shortcut) so that you can apply use to" + Environment.NewLine +
- "open the Display Profile window. This must be a Hotkey that" + Environment.NewLine +
+ "open the Shortcut Library window. This must be a Hotkey that" + Environment.NewLine +
"is unique across all your applications otherwise DisplayMagician" + Environment.NewLine +
"might not see it.";
HotkeyForm scHotkeyForm = new HotkeyForm(testHotkey, hotkeyHeading, hotkeyDescription);
@@ -448,5 +447,6 @@ namespace DisplayMagician.UIForms
return String.Empty;
}
}
+
}
}
diff --git a/DisplayMagician/Properties/Resources.Designer.cs b/DisplayMagician/Properties/Resources.Designer.cs
index 0299759..71e904e 100644
--- a/DisplayMagician/Properties/Resources.Designer.cs
+++ b/DisplayMagician/Properties/Resources.Designer.cs
@@ -71,12 +71,12 @@ namespace DisplayMagician.Properties {
}
///
/// Looks up a localized resource of type System.Drawing.Icon similar to (Icon).
///
- public static System.Drawing.Icon Epic {
+ public static System.Drawing.Bitmap Epic {
get {
object obj = ResourceManager.GetObject("Epic", resourceCulture);
- return ((System.Drawing.Icon)(obj));
+ return ((System.Drawing.Bitmap)(obj));
}
}
@@ -91,12 +91,12 @@ namespace DisplayMagician.Properties {
}
///
/// Looks up a localized resource of type System.Drawing.Icon similar to (Icon).
///
- public static System.Drawing.Icon Origin {
+ public static System.Drawing.Bitmap Origin {
get {
object obj = ResourceManager.GetObject("Origin", resourceCulture);
- return ((System.Drawing.Icon)(obj));
+ return ((System.Drawing.Bitmap)(obj));
}
}
@@ -121,22 +121,22 @@ namespace DisplayMagician.Properties {
}
///
/// Looks up a localized resource of type System.Drawing.Icon similar to (Icon).
///
- public static System.Drawing.Icon Steam {
+ public static System.Drawing.Bitmap Steam {
get {
object obj = ResourceManager.GetObject("Steam", resourceCulture);
- return ((System.Drawing.Icon)(obj));
+ return ((System.Drawing.Bitmap)(obj));
}
}
///
/// Looks up a localized resource of type System.Drawing.Icon similar to (Icon).
///
- public static System.Drawing.Icon Uplay {
+ public static System.Drawing.Bitmap Uplay {
get {
object obj = ResourceManager.GetObject("Uplay", resourceCulture);
- return ((System.Drawing.Icon)(obj));
+ return ((System.Drawing.Bitmap)(obj));
}
}
@@ -71,12 +71,12 @@ namespace DisplayMagician.Properties {
}
///
- /// Looks up a localized resource of type System.Drawing.Icon similar to (Icon).
+ /// Looks up a localized resource of type System.Drawing.Bitmap.
///
@@ -91,12 +91,12 @@ namespace DisplayMagician.Properties {
}
///
- /// Looks up a localized resource of type System.Drawing.Icon similar to (Icon).
+ /// Looks up a localized resource of type System.Drawing.Bitmap.
///
@@ -121,22 +121,22 @@ namespace DisplayMagician.Properties {
}
///
- /// Looks up a localized resource of type System.Drawing.Icon similar to (Icon).
+ /// Looks up a localized resource of type System.Drawing.Bitmap.
///
@@ -121,22 +121,22 @@ namespace DisplayMagician.Properties {
}
///
- /// Looks up a localized resource of type System.Drawing.Icon similar to (Icon).
+ /// Looks up a localized resource of type System.Drawing.Bitmap.
///